@@ -8,8 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.lambda_layer_awscli._jsii
+import aws_cdk.lambda_layer_kubectl._jsii
+
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "awscdk-81-patch", "1.1.0", __name__[0:-6], "awscdk-81-patch@1.1.0.jsii.tgz"
+    "awscdk-81-patch", "1.1.1", __name__[0:-6], "awscdk-81-patch@1.1.1.jsii.tgz"
 )
 
 __all__ = [
